@@ -276,9 +276,9 @@ unitname = NULL, ...)
 	for (unit in names(.lastSuite)) {
 		## Create a new environment for this suite.
 		.ThisTestSuiteEnv <- new.env(parent = .GlobalEnv)
-        ## store it globally so that we can inspect it in case of stop
-		## on error.  but please do not remove the local alias.  #1327
-        assign(".TestSuiteEnv", .ThisTestSuiteEnv, envir = .GlobalEnv)
+        ## Store it in SciViews:TempEnv so that we can inspect it in case of
+		## stop on error. But please do not remove the local alias.  #1327
+        .assignTemp(".TestSuiteEnv", .ThisTestSuiteEnv)
 		## Source the corresponding file
 		Unit <- .lastSuite[[unit]]$file
 		sys.source(Unit, envir = .ThisTestSuiteEnv)
