@@ -425,12 +425,12 @@ msg = "")
 
 .TempEnv <- function ()
 {
-    pos <-  match("TempEnv", search())
+    pos <-  match("SciViews:TempEnv", search())
     if (is.na(pos)) { # Must create it
-        TempEnv <- list()
-        attach(TempEnv, pos = length(search()) - 1)
-        rm(TempEnv)
-        pos <- match("TempEnv", search())
+        `SciViews:TempEnv` <- list()
+        attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+        rm(`SciViews:TempEnv`)
+        pos <- match("SciViews:TempEnv", search())
     }
     return(pos.to.env(pos))
 }
